shithub: hugo

Download patch

ref: d4beef0d2bb8f6481fa80e1d938454a7d4e38814
parent: 51213e0be19fc19dbca9815afa95c73bd6d159c2
author: Bjørn Erik Pedersen <[email protected]>
date: Mon Feb 12 12:32:42 EST 2018

parser: Rename stringifyYAMLMapKeys to stringifyMapKeys

--- a/parser/frontmatter_test.go
+++ b/parser/frontmatter_test.go
@@ -353,7 +353,7 @@
 	}
 
 	for i, c := range cases {
-		res := stringifyYAMLMapKeys(c.input)
+		res := stringifyMapKeys(c.input)
 		if !reflect.DeepEqual(res, c.want) {
 			t.Errorf("[%d] given %q\nwant: %q\n got: %q", i, c.input, c.want, res)
 		}
@@ -387,7 +387,7 @@
 	}
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
-		stringifyYAMLMapKeys(maps[i])
+		stringifyMapKeys(maps[i])
 	}
 }
 
@@ -429,7 +429,7 @@
 	}
 	b.ResetTimer()
 	for i := 0; i < b.N; i++ {
-		stringifyYAMLMapKeys(maps[i])
+		stringifyMapKeys(maps[i])
 	}
 }
 func doBenchmarkFrontmatter(b *testing.B, fileformat string, numTags int) {
--- a/parser/frontmatter.go
+++ b/parser/frontmatter.go
@@ -209,7 +209,7 @@
 	// gotten from `json`.
 	if err == nil {
 		for k, v := range m {
-			m[k] = stringifyYAMLMapKeys(v)
+			m[k] = stringifyMapKeys(v)
 		}
 	}
 
@@ -227,30 +227,30 @@
 	// and change all maps to map[string]interface{} like we would've
 	// gotten from `json`.
 	if err == nil {
-		m = stringifyYAMLMapKeys(m)
+		m = stringifyMapKeys(m)
 	}
 
 	return m, err
 }
 
 // stringifyKeysMapValue recurses into in and changes all instances of
 // map[interface{}]interface{} to map[string]interface{}. This is useful to
 // work around the impedence mismatch between JSON and YAML unmarshaling that's
 // described here: https://github.com/go-yaml/yaml/issues/139
 //
 // Inspired by https://github.com/stripe/stripe-mock, MIT licensed
-func stringifyYAMLMapKeys(in interface{}) interface{} {
+func stringifyMapKeys(in interface{}) interface{} {
 	switch in := in.(type) {
 	case []interface{}:
 		res := make([]interface{}, len(in))
 		for i, v := range in {
-			res[i] = stringifyYAMLMapKeys(v)
+			res[i] = stringifyMapKeys(v)
 		}
 		return res
 	case map[interface{}]interface{}:
 		res := make(map[string]interface{})
 		for k, v := range in {
-			res[fmt.Sprintf("%v", k)] = stringifyYAMLMapKeys(v)
+			res[fmt.Sprintf("%v", k)] = stringifyMapKeys(v)
 		}
 		return res
 	default:
@@ -227,30 +227,30 @@
 }
 
-// stringifyKeysMapValue recurses into in and changes all instances of
+// stringifyMapKeys recurses into in and changes all instances of
 // map[interface{}]interface{} to map[string]interface{}. This is useful to
 // work around the impedence mismatch between JSON and YAML unmarshaling that's